******************************;
* SET UP                      ;
******************************;

	*Change this step as needed:
	*cd "S:\subways\replication_file"
	cd "C:\Users\mturner1\Desktop\replication_file"


	#delimit;
	clear;
	set matsize 2000;
	set more off;
	quietly capture log close;
    log using "Subways and urban growth analysis", replace;

if 1==1{;
***************************************;
*CREATE DATASET FOR LIGHTS REGRESSIONS:;
***************************************;

	*Auxiliary file- linear decay variable creation:;
	use "data/analyze_me2.dta",clear;
	char _dta[omit] prevalent;
	keep if year==1995 | year==2000 |year==2005 |year==2010;
	sort country urbancode year;
	gen quinquenial=(year)/5 -398;
	*Some extra variables:;
	tsset urbancode_n quinquenial;
	sort urbancode_n quinquenial;
	*Ommitted year:;
	char year[omit] 1995;
	encode (urbancode), gen (order);
	sort order year;
	order order;

	keep 
	urbancode year order 
	mean_light_rc1500m don_rc1500m_5km don_rc5km_10km don_rc10km_25km don_rc25km_50km        
	lmean_light_rc1500m ldon_rc1500m_5km ldon_rc5km_10km ldon_rc10km_25km ldon_rc25km_50km 	
	lcitynos1_don_rc750 lcitynos1_don_rc3250 lcitynos1_don_rc7500 lcitynos1_don_rc17500 lcitynos1_don_rc37500    
	lcitynos2_don_rc750 lcitynos2_don_rc3250 lcitynos2_don_rc7500 lcitynos2_don_rc17500 lcitynos2_don_rc37500	 
	lsub1_don_rc750 lsub1_don_rc3250 lsub1_don_rc7500 lsub1_don_rc17500 lsub1_don_rc37500        
	lsub2_don_rc750 lsub2_don_rc3250 lsub2_don_rc7500 lsub2_don_rc17500 lsub2_don_rc37500;

	rename mean_light_rc1500m don_rc1500;
	rename don_rc1500m_5km don_rc5000;
	rename don_rc5km_10km don_rc10000;
	rename don_rc10km_25km don_rc25000;
	rename don_rc25km_50km don_rc50000;

	rename lmean_light_rc1500m ldon_rc750;
	rename ldon_rc1500m_5km ldon_rc3250;
	rename ldon_rc5km_10km ldon_rc7500;
	rename ldon_rc10km_25km ldon_rc17500;
	rename ldon_rc25km_50km  ldon_rc37500;
	tempfile decay;
	save `decay';

	*Generate a database with linear gradient estimates for each city-year:;
	tempname dog2;
	tempfile linear_decay_estimates;
	postfile `dog2'  str6 urbancode year b0 se_b0 t_b0 b1 se_b1 t_b1 r2  using `linear_decay_estimates' , replace;
	
	forvalues i=1/632 {;
			display "calculating light decay for city `i'/632";
			foreach y in 1995 2000 2005 2010 {;
			quietly{;
				use `decay', clear;			
				keep urbancode year order ldon_rc*;
				keep if order==`i';
				keep if year==`y';
				drop year order;
				reshape long ldon_rc, i(urbancode) j(distance);
				gen year=`y';
				sum year;
				scalar year_=r(mean);
				scalar u=urbancode[1];
				gen ldistance=log(distance);
				reg ldon_rc ldistance;
				post `dog2' (u) (year_) (_b[_cons]) (_se[_cons]) (_b[_cons]/_se[_cons])  (_b[ldistance])  (_se[ldistance]) (_b[ldistance]/_se[ldistance]) (e(r2));
				};
			};
		};
	postclose `dog2';
	use "`linear_decay_estimates'",clear;
	save "data/linear_decay_estimates.dta", replace;

	*Merge workhorse dataset with lights decay estimates:;
	use "data/analyze_me2.dta",clear;
	char _dta[omit] prevalent;
	keep if year==1995 | year==2000 |year==2005 |year==2010;
	sort country urbancode year;
	gen quinquenial=(year)/5 -398;
	*Some extra variables:;
	tsset urbancode_n quinquenial;
	sort urbancode_n quinquenial;
	*Ommitted year:;
	char year[omit] 1995;

	merge 1:1 urbancode year using "data/linear_decay_estimates.dta";
	drop _merge;
	rename b0 linear_b0;
	rename se_b0 linear_se_b0;
	rename t_b0 linear_t_b0;
	rename b1 linear_b1;
	rename se_b1 linear_se_b1;
	rename t_b1 linear_t_b1;
	rename r2 linear_r2;
	
	*Generate Change in Slope and Change in Intercept:;
	sort country urbancode year;
	by country urbancode: gen Dlinear_b1=linear_b1[_n]-linear_b1[_n-1] if year[_n]-5==year[_n-1];
	label var Dlinear_b1 "\$\Delta (Linear gradient_t) \$";

	by country urbancode: gen Dlinear_b0=linear_b0[_n]-linear_b0[_n-1] if year[_n]-5==year[_n-1];
	label var Dlinear_b0 "\$\Delta (Linear intercept_t) \$";

	save "data/analyze_me2_lights.dta", replace;
	erase "data/linear_decay_estimates.dta";

************************************************;
*END OF DATASET CREATION FOR LIGHTS REGRESSIONS:;
************************************************;
};


if 1==1{;
********************************;
*TABLE 1- DESCRIPTIVE STATISTICS;
********************************;
		
	use "data/analyze_me2.dta",clear;
	*Top panel (All cities, column 1 - World):;
		keep if year==2010;
		gen one=1;
		*N:;
		sum one;

		egen y=mean(pop);
		gen x=y/1000;
		*Mean population (in thousands):;
		sum x,d;
		drop x y;
		
		egen x=mean(lpop);
		*Mean log(pop):;
		sum x,d;
		drop x ;

		*Note that changes are averaged over 1950-2010 period:;
		use "data/analyze_me2.dta",clear;
		keep if year>=1950;
		keep if !mod(year,5);

		egen x=mean(Dlpop);
		sum x,d;
		drop x ;
		
		egen x=mean(D2lpop);
		sum x,d;
		drop x ;
		
		use "data/analyze_me2_lights.dta", clear;
		keep if year==2010;
		
		sum linear_b1;
		sum linear_b0;


	*Top panel (All cities, Columns 2-6, by continent):;
		global continents "Africa Asia Europe "North America" "South America" ";
		foreach x in $continents {;
		display "`x'";

		use "data/analyze_me2.dta",clear;
		keep if year==2010;
		keep if continent=="`x'";
		gen one=1;
		*N:;
		sum one;

		egen y=mean(pop);
		gen x=y/1000;
		*Mean population (in thousands):;
		sum x,d;
		drop x y;
		
		egen x=mean(lpop);
		*Mean log(pop):;
		sum x,d;
		drop x ;

		*Note that changes are averaged over 1950-2010 period:;
		use "data/analyze_me2.dta",clear;
		keep if year>=1950;
		keep if !mod(year,5);
		keep if continent=="`x'";

		egen x=mean(Dlpop);
		sum x,d;
		drop x ;
		
		egen x=mean(D2lpop);
		sum x,d;
		drop x ;
		
		use "data/analyze_me2_lights.dta", clear;
		keep if year==2010;
		keep if continent=="`x'";
		
		sum linear_b1;
		sum linear_b0;
		};

		

	*Bottom panel : Subway cities;
	*Column 1 World:;
		use "data/analyze_me2.dta",clear;
		keep if year==2010;
		keep if sub2010>0;
		gen one=1;

		*N:;
		sum one;
		
		*Total stations:;
		egen x=total(operational);
		sum x;
		drop x;

		*Total route km:;
		egen x=total(op_km);
		sum x;
		drop x;

		*Mean stations:;
		sum operational;

		*Mean route km:;
		sum op_km;		

		*Mean subway lines:;
		sum subway_lines;

		*Mean log stations:;
		sum lop;

		*Mean population;;
		sum pop;

		*Mean log population;;
		sum lpop;
		
		*Mean light in 25km disk:;
		sum mean_light_rc25km;


		*For changes take 1950-2010 average;
		use "data/analyze_me2.dta",clear;
		keep if year>=1950;
		keep if sub2010>0;
		keep if !mod(year,5);
		
		*Mean change in subway stations:;
		sum Dop;
		*Mean change in log subway stations:;
		sum Dlop;
		*Mean change in log population:;
		sum Dlpop;
		*Mean second difference in log population:;
		sum D2lpop;

		use "data/analyze_me2_lights.dta", clear;
		keep if year==2010;
		keep if sub2010>0;
		
		corr mean_light_rc25km pop;
		sum linear_b1;
		sum linear_b0;


	*Bottom panel (Subway cities, Columns 2-6, by continent):;
		local count=1;
		global continents "Africa Asia Europe "North America" "South America" ";
		foreach x in $continents {;
		display "`x'";
		use "data/analyze_me2.dta",clear;
		keep if year==2010;
		keep if sub2010>0;
		keep if continent=="`x'";
		gen one=1;

		*N:;
		sum one;
		
		*Total stations:;
		egen x=total(operational);
		sum x;
		drop x;

		*Total route km:;
		egen x=total(op_km);
		sum x;
		drop x;

		*Mean stations:;
		sum operational;

		*Mean route km:;
		sum op_km;		

		*Mean subway lines:;
		sum subway_lines;

		*Mean log stations:;
		sum lop;

		*Mean population;;
		sum pop;

		*Mean log population;;
		sum lpop;
		
		*Mean light in 25km disk:;
		sum mean_light_rc25km;


		*For changes take 1950-2010 average;
		use "data/analyze_me2.dta",clear;
		keep if year>=1950;
		keep if sub2010>0;
		keep if !mod(year,5);
		keep if continent=="`x'";
		
		*Mean change in subway stations:;
		sum Dop;
		*Mean change in log subway stations:;
		sum Dlop;
		*Mean change in log population:;
		sum Dlpop;
		*Mean second difference in log population:;
		sum D2lpop;

		use "data/analyze_me2_lights.dta", clear;
		keep if year==2010;
		keep if sub2010>0;
		keep if continent=="`x'";
		
		*Correlation lights and population:;
		if `count'>1 {;
		corr mean_light_rc25km pop ;
		};
		
		sum linear_b1;
		sum linear_b0;
		local count=`count'+1;
		};

****************;
*End of Table 1 ;
****************;
};

		
	
if 1==1{;
********************************************;
*Table 2: Public transit ridership (2010) descriptive statistics table:;
********************************************;
	use "data/analyze_me2.dta",clear;

	sum ridershipheavyrail ridershipbuses  if year==2010,d;
	sum ridershipbuses if ridershipheavyrail!=. & year==2010,d;

	sum subway_ridership_pc bus_ridership_pc if year==2010 ,d;
	sum bus_ridership_pc  if subway_ridership_pc!=. & year==2010,d;
	
	tab country if   subway_ridership!=. & year==2010;
	tab country if  bus_ridership_pc!=. & year==2010;
	tab country if  bus_ridership_pc!=. & subway_ridership_pc!=. & year==2010;

	sum pop if   subway_ridership!=. & year==2010;
	sum pop if  bus_ridership_pc!=. & year==2010;
	sum pop if  bus_ridership_pc!=. & subway_ridership_pc!=. & year==2010;

****************;
*End of Table 2 ;
****************;
};


	
	
if 1==1{;
******************************************;
*Figure 1: Growth of world subway systems:;
******************************************;

*Graph of subway stations over time:;
	use "data/analyze_me2.dta",clear;
	*Subway system dummy;
	gen Subway=0;
	replace Subway=1 if year_start<=year & year_start<=2010;
	collapse (sum) operational Subway,by(year);
	twoway (line operational year, clcolor(black) scheme(s1mono) ) (line Subway year ,   ytitle("Subway stations") ytitle("Cities with subway system" , axis(2)) yaxis(2) lpattern(dash) xlab(1870(20)2010) xmticks(##5) legend(label(1 "Subway stations (left axis)") label(2 "Cities with subway (right axis)") region(lwidth(none))));
	graph export "output/figure_1.png", replace;

****************;
*End of Figure 1;
****************;
};




if 1==1 {;
****************************************************;
*Figure 3: Proportion of cities with subway systems:;
****************************************************;

	use "data/analyze_me2.dta",clear;
	keep if year==2010;
	gen Subway=0;
	replace Subway=1 if year_start!=. & year_start<=2010;
	drop if urbanname=="Tokyo";

	gen pop_m=pop/1000000;
	gen popmill=round(pop_m, .5);
	label var popmill "Pop. in Millions (rounded)";
	table popmill , c(n Subway mean Subway sd Subway median Subway);
	sort popmill Subway;
	by popmill: egen snitt=mean(Subway);
	lpoly Subway pop_m, deg(1) bw(6) gen(x y) ci se(se1) nogr kernel(triangle);
	gen k=1.96;
	gen ci1l=y-k*se1;
	gen ci1h=y+k*se1;

	drop snitt x y se1 k ci1l ci1h;

	drop if popmill>22;
	bysort popmill developed_country: egen snitt=mean(Subway);
	lpoly Subway pop_m if developed_country==1, deg(1) bw(5) gen(x_dev y_dev) ci se(se1_dev) nogr kernel(triangle);
	lpoly Subway pop_m if developed_country==0, deg(1) bw(5) gen(x y) ci se(se1) nogr kernel(triangle);
	twoway (line y_dev x_dev, lcolor(gs9) lpattern(solid) mlw(vthick) scheme(s1mono) legend( off )) (line y x, lcolor(black) lpattern(dash)) (scatter snitt popmill if developed_country==1, mcolor(gs9) msize(med) xscale(r(0 22))) (scatter snitt popmill if developed_country==0, mcolor(black) msize(small) m(triangle)), legend( label(1 "Developed countries") label(2 "Underdeveloped countries")  order(1 2) region(lpattern(blank)))  ylabels(0(.2)1.3)  xtitle("Population in millions") ytitle("Proportion with subway system");
	graph export "output/figure_3.png", replace;

****************;
*End of Figure 3;
****************;
};


if 1==1 {;
************************************************;
*Table 3: Population and subway stations (2010):;
************************************************;

	use "data/analyze_me2.dta",clear;
	keep if year==2010;
	gen x=-pop;
	sort x;
	drop x;
	gen stations_pp=100000*(operational/pop);
	br urbanname pop operational stations_pp in 1/90;
***************;
*End of table 3;
***************;
};



if 1==1 {;
*****************************************;
*Figures 4, 5, and 6: Event study graphs:;
*****************************************;

	use "data/analyze_me2.dta",clear;
	char _dta[omit] prevalent;
	keep if !mod(year,5);
	drop if year<1950;
	eststo clear; 		
	sort country urbancode year;
	gen quinquenial=year/5;
	xtset urbancode_n quinquenial;

	*t=0 is beginning of subway system:;
	sort country urbancode year;
	gen aux=year if subway==1 & subway[_n-1]==0 & urbancode==urbancode[_n-1];
	egen aux2=max(aux),by(urbancode);
	gen t=year-aux2;
	drop aux aux2;
	gen one=1;
	gen se_Dlpop=Dlpop;
        preserve;
		keep if t!=.;
		by urbancode, sort: gen nvals = _n == 1;
		count if nvals; 
		sum nvals, d;
		global obs=r(sum);
		drop nvals;
		collapse (mean) Dlpop Dlop (semean) se_Dlpop (sum) one, by(t);
	    	label var one "Num. observations";
	    	label var Dlpop "Change in log population";
	    	gen k=1.96;
	    	gen cil=Dlpop-k*se_Dlpop;
	    	gen cih=Dlpop+k*se_Dlpop;
    	
    *Figure 6: 55 years around subway opening:;
		display $obs;
		twoway (line cil t, lcolor(gs2) lpattern(dash) scheme(s1mono) legend(off) ) (line cih t, lcolor(gs2) lpattern(dash)) (line Dlpop t if t!=.,  lpattern(solid) xline(0) legend(off) ytitle(Change in log population) xlabel(-50(10)50) note(N=$obs) );
		graph export "output/figure_6.png", replace;
        restore;

        preserve;
		keep if t!=.;
		gen bux=1 if t>=-20 & t<=20;
		egen bux2=sum(bux), by(urbancode);
		keep if bux2==9 & bux==1;
		by urbancode, sort: gen nvals = _n == 1;
		count if nvals; 
		sum nvals, d;
		global obs=r(sum);
		drop nvals;
		collapse (mean) Dlpop Dlop (semean) se_Dlpop (sum) one, by(t);
	    	label var one "Num. observations";
	    	label var Dlpop "Change in log population";
	    	gen k=1.96;
	    	gen cil=Dlpop-k*se_Dlpop;
	    	gen cih=Dlpop+k*se_Dlpop;
    *Figure 4: 20 years years around subway opening. Constant sample:;
		twoway (line cil t , lcolor(gs2) lpattern(dash) scheme(s1mono)) (line cih t , lcolor(gs2) lpattern(dash)) (line Dlpop t ,  lpattern(solid) xline(0) legend(off) ytitle(Change in log population) xlabel(-20(5)20) note(N=$obs) );
		graph export "output/figure_4.png", replace;
       restore;	

       preserve;	
		drop se_Dlpop;
		keep if t!=.;
		gen bux=1 if t>=-20 & t<=20 ;
		egen bux2=sum(bux), by(urbancode);
		keep if bux2==9 & bux==1;
		areg Dlpop i.year ,a(continent);
		predict resid, residuals;
		gen se_resid=resid;
		by urbancode, sort: gen nvals = _n == 1;
		count if nvals; 
		sum nvals, d;
		global obs=r(sum);
		drop nvals;
		collapse (mean) resid Dlop (semean) se_resid (sum) one, by(t);
	    	label var one "Num. observations";
	    	label var resid "Change in log population - after controlling for year and continent f.e.";
	    	gen k=1.96;
	    	gen cil=resid-k*se_resid;
	    	gen cih=resid+k*se_resid;
		*Residuals from year F.E. and continent F.E. - 20 years around subway opening, constamt sample;
		twoway (line cil t if t>=-20 & t<=20, lcolor(gs2) lpattern(dash) scheme(s1mono)) (line cih t if t>=-20 & t<=20, lcolor(gs2) lpattern(dash)) (line resid t if t>=-20 & t<=20,  lpattern(solid) xline(0) legend(off) ytitle(Change in log population) xlabel(-20(5)20) note(N=$obs) );
		graph export "output/figure_5.png", replace;
	restore; 
*********************;
*End of figures 4,5,6;
*********************;
};



if 1==1 {;
*******************************************************************************;
*Table 4: Mean city-year population growth rates by time to a subway expansion:;
*******************************************************************************;

*Panel A of city growth around subway expansions ;
	use "data/analyze_me2.dta",clear;
	char _dta[omit] prevalent;
	keep if !mod(year,5);
	drop if year<=1950;
	eststo clear; 		
	sort country urbancode year;
	gen quinquenial=year/5;
	xtset urbancode_n quinquenial;

	*case 1: expansion sequence: Y, N:;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n+1]==0  & urbancode==urbancode[_n+1];
		reg Dlpop if aux==1;
		gen aux2=0;
		replace aux2=1 if aux[_n-1]==1  & urbancode==urbancode[_n-1];
		reg Dlpop if aux2==1;
		gen aux3=1 if aux==1 | aux2==1;
		reg Dlpop aux if aux3==1, cluster(urbancode);

	*case 2: expansion sequence: Y, N, N:;
		drop aux aux2 aux3;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n+1]==0 & Dlop[_n+2]==0 & urbancode==urbancode[_n+2];
		*mean rate t;
		reg Dlpop if aux==1;
		gen aux2=0;
		replace aux2=1 if aux[_n-1]==1 & urbancode==urbancode[_n-1];
		*mean rate t+1;
		reg Dlpop if aux2==1;
		gen aux3=0;
		replace aux3=1 if aux[_n-2]==1 & urbancode==urbancode[_n-2];
		*mean rate t+2;
		reg Dlpop if aux3==1;
		*compare t and t+1;
		reg Dlpop aux if aux==1 | aux2==1,cluster(urbancode);
		*compare t and t+2;
		reg Dlpop aux if aux==1 | aux3==1 ,cluster(urbancode);

	*case 3: expansion sequence: N, Y:;
		drop aux aux2 aux3;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n-1]==0 & urbancode==urbancode[_n-1];
		reg Dlpop if aux==1;
		gen aux2=0;
		replace aux2=1 if aux[_n+1]==1 & urbancode==urbancode[_n+1];
		reg Dlpop if aux2==1;
		gen aux3=1 if aux==1 | aux2==1;
		reg Dlpop aux if aux3==1, cluster(urbancode);

	*case 4: expansion sequence: N, N, Y:;
		drop aux aux2 aux3;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n-1]==0 & Dlop[_n-2]==0 & urbancode==urbancode[_n-2];
		*mean rate t;
		reg Dlpop if aux==1;
		gen aux2=0;
		replace aux2=1 if aux[_n+1]==1 & urbancode==urbancode[_n+1];
		*mean rate t-1;
		reg Dlpop if aux2==1;
		gen aux3=0;
		replace aux3=1 if aux[_n+2]==1 & urbancode==urbancode[_n+2];
		*mean rate t-2;
		reg Dlpop if aux3==1;
		*compare t and t-1;
		reg Dlpop aux if aux==1 | aux2==1,cluster(urbancode);
		*compare t and t-2;
		reg Dlpop aux if aux==1 | aux3==1,cluster(urbancode);


	*case 5: expansion sequence: N, Y, N:;
		drop aux aux2 aux3;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n-1]==0 & Dlop[_n+1]==0 & urbancode==urbancode[_n-1] & urbancode==urbancode[_n+1];
		*mean rate t;
		reg Dlpop if aux==1;
		gen aux2=0;
		replace aux2=1 if aux[_n-1]==1 & urbancode==urbancode[_n-1];
		*mean rate t+1;
		reg Dlpop if aux2==1;
		gen aux3=0;
		replace aux3=1 if aux[_n+1]==1 & urbancode==urbancode[_n+1];
		*mean rate t-1;
		reg Dlpop if aux3==1;
		*compare t and t+1;
		reg Dlpop aux if aux==1 | aux2==1,cluster(urbancode);
		*compare t and t-1;
		reg Dlpop aux if aux==1 | aux3==1,cluster(urbancode);

	*end of table A of city growth around subway stations;


*Panel B of city growth around subway expansions with year and continent fixed effects;
	
	use "data/analyze_me2.dta",clear;
	char _dta[omit] prevalent;
	keep if !mod(year,5);
	drop if year<=1950;
	tab year,gen(yearq_);
	tab continent,gen(continentd_);
	eststo clear; 		
	sort country urbancode year;
	gen quinquenial=year/5;
	xtset urbancode_n quinquenial;

	cap drop se_Dlpop;
	*t=0 is beginning of subway system:;
	sort country urbancode year;
	gen aux=year if subway==1 & subway[_n-1]==0 & urbancode==urbancode[_n-1];
	egen aux2=max(aux),by(urbancode);
	gen t=year-aux2;
	drop aux aux2;
	gen one=1;

	*case 1: expansion sequence: Y, N:;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n+1]==0 & urbancode==urbancode[_n+1];
		egen x=group(urbanname) if aux==1;
		*max of x is the number of cities:;
		sum x;
		drop x;
		gen aux2=0;
		replace aux2=1 if aux[_n-1]==1 & urbancode==urbancode[_n-1];
		reg Dlpop aux aux2 i.year continentd_*, cluster(urbancode);
		test aux2-aux=0;
		display _b[aux2]-_b[aux];

	*case 2: expansion sequence: Y, N, N:;
		drop aux aux2;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n+1]==0 & Dlop[_n+2]==0 & urbancode==urbancode[_n+2];
		egen x=group(urbanname) if aux==1;
		*max of x is the number of cities:;
		sum x;
		drop x;
		gen aux2=0;
		replace aux2=1 if aux[_n-1]==1 & urbancode==urbancode[_n-1];
		gen aux3=0;
		replace aux3=1 if aux[_n-2]==1 & urbancode==urbancode[_n-2];
		reg Dlpop aux aux2 aux3 i.year continentd_*, cluster(urbancode);
		test aux2-aux=0;
		display _b[aux2]-_b[aux];
		test aux3-aux=0;
		display _b[aux3]-_b[aux];
		
	*case 3: expansion sequence: N, Y:;
		drop aux aux2 aux3;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n-1]==0 & urbancode==urbancode[_n-1];
		egen x=group(urbanname) if aux==1;
		*max of x is the number of cities:;
		sum x;
		drop x;
		gen aux2=0;
		replace aux2=1 if aux[_n+1]==1 & urbancode==urbancode[_n+1];
		reg Dlpop aux aux2 i.year continentd_*, cluster(urbancode);
		test aux2-aux=0;
		display _b[aux2]-_b[aux];

	*case 4: expansion sequence: N, N, Y:;
		drop aux aux2;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n-1]==0 & Dlop[_n-2]==0 & urbancode==urbancode[_n-2];
		egen x=group(urbanname) if aux==1;
		*max of x is the number of cities:;
		sum x;
		drop x;
		gen aux2=0;
		replace aux2=1 if aux[_n+1]==1 & urbancode==urbancode[_n+1];
		gen aux3=0;
		replace aux3=1 if aux[_n+2]==1 & urbancode==urbancode[_n+2];
		reg Dlpop aux aux2 aux3 i.year continentd_*, cluster(urbancode);
		test aux2-aux=0;
		display _b[aux2]-_b[aux];
		test aux3-aux=0;
		display _b[aux3]-_b[aux];

	*case 5: expansion sequence: N, Y, N:;
		drop aux aux2 aux3;
		sort urbancode year;
		gen aux=0;
		replace aux=1 if Dlop>0 & Dlop[_n-1]==0 & Dlop[_n+1]==0 & urbancode==urbancode[_n-1] & urbancode==urbancode[_n+1];
		egen x=group(urbanname) if aux==1;
		*max of x is the number of cities:;
		sum x;
		drop x;
		gen aux2=0;
		replace aux2=1 if aux[_n-1]==1 & urbancode==urbancode[_n-1];
		gen aux3=0;
		replace aux3=1 if aux[_n+1]==1 & urbancode==urbancode[_n+1];
		reg Dlpop aux aux2 aux3 i.year continentd_*, cluster(urbancode);
		test aux2-aux=0;
		display _b[aux2]-_b[aux];
		test aux3-aux=0;
		display _b[aux3]-_b[aux];

***************;
*End of Table 4;
***************;
};



if 1==1 {;
********************************************;
*Table 5: Pooled cross sectional estimation:;
********************************************;
	use "data/analyze_me2.dta",clear;
	char _dta[omit] prevalent;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	tsset urbancode_n quinquenial;
	sort urbancode_n quinquenial;
	eststo clear; 		

	*(1) *Dep var: lpop, Sample: all, x's lop;
		cap drop resid Lresid x nvals;
		eststo: reg lpop lop , cluster(urbancode);
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(2)-Dep var: lpop, Sample: all, x's lop, lgdp, logcountry pop, year*continent dummies, geography;
		eststo: xi: reg lpop lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent , cluster(urbancode); 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*FOR TEXT ONLY: SUBWAY DUMMY . Dep var: lpop, Sample: all. X's: subwaydummy , lop, lgdp, logcountry pop, year*continent dummies, geography;;
		*We add subway dummy to distingush any effect from having a subway system vs expansion effects;
		xi: reg lpop lop subway lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER i.quinquenial*i.continent , cluster(urbancode); 		

	*(3)-Dep var: lpop, Sample: Subway cities, X's: lop, lgdp, logcountry pop, year*continent dummies, geography;
		eststo: xi: reg lpop lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER i.quinquenial*i.continent if sub2010>0 , cluster(urbancode); 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(4)-Big cities 1970. Dep var: lpop, Sample: Subway cities, X's: lop, lgdp, logcountry pop, year*continent dummies, geography;
		eststo: xi: reg lpop lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER i.quinquenial*i.continent if sub2010>0 &  big_city_1970==1, cluster(urbancode); 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(5)-Dep var: lpop, Sample: Subway cities, X's: l_op_km, lgdp, logcountry pop, year*continent dummies, geography;
		cap drop resid Lresid x nvals;
		eststo: xi: reg lpop log_op_km lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER i.quinquenial*i.continent if sub2010>0 , cluster(urbancode); 		
		estadd ysumm;
		sum log_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(6)-Dep var: lpop, Sample: Subway cities, X's: Subway_lines, lgdp, logcountry pop, year*continent dummies, geography;
		cap drop resid Lresid x nvals;
		eststo: xi: reg lpop log_lines lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode); 		
		estadd ysumm;
		sum log_lines if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*FOR TEXT ONLY: Levels regression (not logs);
	        *Dep var: pop, Sample: Subway cities with pop over 1m in 1970, x's lop, lgdp, yeardummies, geography;
		xi: reg pop operational lcountry_pop lgdp capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode); 		

	*FOR TEXT ONLY: TEN YEAR PANEL:;
		use "data/analyze_me2.dta",clear;
		char _dta[omit] prevalent;
		keep if !mod(year,10);
		drop if year<1950;
		gen decenial=year/10-195;
		tsset urbancode_n decenial;
		sort urbancode_n decenial;
		*Dep var: lpop, Sample: Subway cities with pop over 1m in 1970, x's lop, lgdp, yeardummies, geography;
		xi: reg lpop lop lcountry_pop lgdp capital lKM_OCEAN lKM_RIVER lKM_BORDER i.decenial*i.continent if  sub2010>0 , cluster(urbancode); 		

	*7)-Log lights:;
		*Dep var: log mean lights 25km , Sample: Subway cities, X's: lop, lgdp, logcountry pop, year*continent dummies, geography;
		cap drop resid Lresid x nvals;
		use "data/analyze_me2.dta",clear;
		char _dta[omit] prevalent;
		keep if year==1995 | year==2000 |year==2005 |year==2010;
		sort country urbancode year;
		gen quinquenial=(year)/5 -398;
		tsset urbancode_n quinquenial;
		sort urbancode_n quinquenial;
		char year[omit] 1995;

		eststo: xi: reg lmean_light_rc25km lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent if sub2010>0, cluster(urbancode) ; 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*Table x_section;		
		esttab using  "output/table_5.tex", replace b(%10.2fc) se(2)  	
		label star(* 0.10 ** 0.05 *** 0.001)
		mtitles("\$\ln(\text{pop}_t)  \$" "\$\ln(\text{pop}_t)\$"    "\$\ln(\text{pop}_t)\$"  "\$\ln(\text{pop}_t)\$" "\$\ln(\text{pop}_t)\$" "\$\ln(\text{pop}_t)\$"  "\$\ln(\text{Lights}_t)\$")
		mgroups("\multicolumn{2}{c}{All cities}&\multicolumn{4}{c}{Subway cities} \\ \cmidrule(r){2-3} \cmidrule(l){4-8}")
		order(lop  log_op_km  log_lines lgdp lcountry_pop)
		scalars("ymean Mean of dep. variable"  "mean_sub Mean of subways regressor" "sd_sub SD subways regressor" "N Observations" "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods" )
		sfmt(%10.2f %10.2f %10.2f %10.2f %10.2f %10.0f %10.0f %10.0f )
		obslast substitute(\_ _) drop(_cons  ) 	indicate("Geographic controls=lKM_OCEAN lKM_RIVER lKM_BORDER capital _Icontinent_*" "YearXContinent dummies=*quiXcon*   _Iquinqueni* *_Iquinqueni*")
		nonotes addnotes("Dependent variable: Log population of metropolitan area in quinquennial period t (except last column see (7) below). " 
		"City-level clustered standard errors in parentheses. Stars denote significance levels: * 0.10, ** 0.05, *** 0.01."
		"Geographic controls are capital city dummy, log km to ocean, log km to land border, and log km to navigable river."
		"(1)- Pooled cross section. (2)- Geographic controls, GDP pc control, country population,  and year-by-continent dummies."
		"(3)- Restrict sample to cities with subway by 2010. (4)- Restrict sample to large cities in 1970 (population $>$ 1 million)."
		"(5)- Log route km of subways as main regressor. Sample is cities with subway by 2010."
		"(6)- Log subway lines in system as main regressor. Sample is cities with subway by 2010."
		"(7)- Dep. var. is log mean radiance calibrated lights in a 25km circle around the centroid of the city in quinquennial period t.");

***************;
*End of table 5;
***************;
};






if 1==1 {;
********************************************;
*Table 6: First differences estimation:;
********************************************;

	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	sort country urbancode year;
	xtset urbancode_n quinquenial;

        *City specific linear and quadratic time trends;
	gen x=quinquenial;
	egen group = group(urbancode_n);
	su group, meanonly;
    	    foreach i of num 1/`r(max)' {;
	    qui gen dummy`i'=0;
	    qui replace dummy`i'=1 if group==`i';
	    qui gen timetrendcity_`i'=x*dummy`i';
    	   };
    	drop dummy* x;
        *City specific quadratic time trend:;
        local j=1;
        su group, meanonly;
            while `j' <=`r(max)' {;
            cap gen timetrendcity2_`j'=timetrendcity_`j'*timetrendcity_`j';
            local j=`j'+1;
            display `j';
            };
	*Ommitted year:;
	char year[omit] 2010;
	eststo clear; 		

	*(1)- FD regression, no controls. Sample: Subway cities ;
		eststo:  xi: reg Dlpop Dlop if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(2)- Add yearXcontinent dummies;
		eststo: xi: reg Dlpop Dlop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode) ;
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(3)- Add other controls.;
		eststo:  xi: reg Dlpop Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(4)- Large cities 1970.;
		eststo:  xi: reg Dlpop Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  &  big_city_1970==1 , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(5)- Control for bus ridership changes.;
		eststo:  xi: reg Dlpop Dlop Dlgdp Dlcountry_pop Dlog_ridershipbuses i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(6)- Use Dlog km;
		eststo:  xi: reg Dlpop Dlog_op_km Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(7)- Use Dlog lines;
		eststo:  xi: reg Dlpop Dlog_lines Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		sum Dlog_lines if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(8)- Same as 4, DEPVAR: D lights share;
		cap drop resid Lresid x nvals;
		use "data/analyze_me2.dta",clear;
		keep if year==1995 | year==2000 |year==2005 |year==2010;
		sort country urbancode year;
		gen quinquenial=(year)/5 -398;
		tsset urbancode_n quinquenial;
		sort urbancode_n quinquenial;
		*Ommitted year:;
		char year[omit] 1995;
		eststo:  xi: reg Dlmean_light_rc25km Dlop Dlgdp Dlcountry_pop  i.quinquenial*i.continent if sub2010>0, cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(9)- Ten year panel;
		use "data/analyze_me2.dta",clear;
		char _dta[omit] prevalent;
		keep if !mod(year,10);
		drop if year<1950;
		gen decenial=year/10-195;
		tsset urbancode_n decenial;
		sort urbancode_n decenial;
		eststo: xi: reg Dlpop Dlop Dlgdp Dlcountry_pop i.decenial*i.continent if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(10) Long difference 50-00;
		use "data/analyze_me2.dta",clear;
		keep if !mod(year,5);
		drop if year<1950;
		gen quinquenial=year/5-389;
		sort country urbancode year;
		xtset urbancode_n quinquenial;
		char year[omit] 2010;
		eststo: xi: reg dlpop_50to00 Dlop_50to00 dlgdp_50to00 dlcountry_pop_50to00  i.continent if year==2010 & sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_lines if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	
		sum dlpop_50to10 if e(sample);
		sum Dlop_50to10 if e(sample);

		esttab using  "output/table_6.tex", replace b(%10.3fc) se(3)  	
		label star(* 0.10 ** 0.05 *** 0.001) 	
	        mtitles("\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$ \Delta \ln{(\text{pop}_t)}\$" "\$ \Delta \ln{(\text{pop}_t)}\$" "\$ \Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln(\text{Lights}_t)\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_{50-00})}\$"      )
		order(Dlop Dlop_50to00  Dlog_op_km Dlog_lines  Dlog_ridershipbuses  Dlgdp Dlcountry_pop )
		substitute(\_ _)
		scalars("ymean Mean of dep. variable"  "mean_sub Mean of subways regressor" "sd_sub SD subways regressor" "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"  "N Observations" )
		sfmt(%10.3f %10.2f %10.2f %10.2f %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.2f ) obslast drop(_cons dlcountry_pop_50to00 dlgdp_50to00) 
		indicate("YearXContinent dummies=*quiXcon*    *_Iquinqueni*  *_Iquinqueni* *_Idecenial* *IdecXcon_* _Icontinent_* *continent_*"  )
 		nonotes 
 		addnotes("Sample is subway cities. City-level clustered standard errors in parentheses. Stars denote significance levels: * 0.10, ** 0.05, *** 0.01."
        "(1)- No controls. (2)- Add year-by-continent dummies. (3)- Add change in log gdp and change in log country pop. controls."
        "(4)- Restrict sample to large cities in 1970 (population $>$ 1 million). (5)- Control for change in log bus ridership. (6)- Use change in log route km as main regressor."
        "(7)- Use change in log subway lines as main regressor.  (8)- Dep. var. is change in log mean radiance calibrated lights in a 25km circle around the centroid of the city."
        "(9)- 10 year panel analysis. (10)- Long difference regression 1950-2000, control for \$\Delta \ln(\textsc{GDP}pc_{50-00})\$ and \$\Delta \ln(\textsc{Country\;pop}_{50-00})\$." );

***************;
*End of table 6;
***************;
};






if 1==1 {;
********************************************;
*Table 7: Robustness to confounding dynamics:;
********************************************;
	
	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	sort country urbancode year;
	xtset urbancode_n quinquenial;
	char year[omit] 2010;
	eststo clear;

	*(1)- OLS. Control for lag 2 dependent variable;
		eststo:  xi: reg Dlpop Dlop Dlgdp Dlcountry_pop L2Dlpop  i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(2)- OLS. Control for lag 3 dependent variable;
		eststo:  xi: reg Dlpop Dlop Dlgdp Dlcountry_pop L2Dlpop L3Dlpop  i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(3)- OLS. Second differences regression;
		eststo:  xi: reg D2lpop D2lop D2lgdp D2lcountry_pop i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum D2lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(4)- IV L4lop;
		xi: reg Dlop L4lop Dlgdp L2Dlpop  Dlcountry_pop i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		test L4lop=0;
		local F= r(F);
		eststo:  xi: ivregress 2sls Dlpop Dlgdp L2Dlpop  Dlcountry_pop i.quinquenial*i.continent (Dlop=L4lop) if  sub2010>0  , cluster(urbancode);
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(5)- IV L4lop, control for L3DLpop too;
		xi: reg Dlop L4lop Dlgdp  L2Dlpop L3Dlpop   Dlcountry_pop i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		test L4lop=0;
		local F= r(F);
		eststo:  xi: ivregress 2sls Dlpop Dlgdp  L2Dlpop L3Dlpop   Dlcountry_pop i.quinquenial*i.continent (Dlop=L4lop) if  sub2010>0  , cluster(urbancode);
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(6)- ;
		xi: reg Dlop L8lop Dlgdp L2Dlpop  Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		test L8lop=0;
		local F= r(F);
		eststo:  xi: ivregress 2sls Dlpop Dlgdp L2Dlpop  Dlcountry_pop i.quinquenial*i.continent (Dlop=L8lop) if sub2010>0   , cluster(urbancode);
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(7)- ;
		xi: reg Dlop L4lop Dlgdp L2lpop  Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		test L4lop=0;
		local F= r(F);		
	        eststo: xi: ivregress 2sls Dlpop Dlgdp L2lpop  Dlcountry_pop i.quinquenial*i.continent (Dlop=L4lop) if  sub2010>0  , cluster(urbancode); 
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	
	
		esttab using  "output/table_7.tex", replace b(%10.3fc) se(3)  	
		label star(* 0.10 ** 0.05 *** 0.001) 	mtitles("\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta^2\ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$" "\$\Delta \ln{(\text{pop}_t)}\$")
		order(Dlop D2lop L2Dlpop  L3Dlpop  L2lpop  Dlcountry_pop  Dlgdp D2lcountry_pop  D2lgdp )
		substitute(\_ _)
		scalars("ymean Mean of dep. variable"  "mean_sub Mean of subways regressor" "sd_sub SD subways regressor" "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"   "F_iv F-stat excluded instrument" "N Observations" )
		sfmt(%10.3f %10.2f %10.2f %10.2f %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.2f ) obslast drop(_cons ) 
		indicate("YearXContinent dummies=*quiXcon*    *_Iquinqueni*  *_Iquinqueni*  _Icontinent_* *continent_*"   )
 		nonotes addnotes("Dependent variable: Change in log population of metropolitan area in a 5 year period. Sample is subway cities."
		"City-level clustered standard errors in parentheses. Stars denote significance levels: * 0.10, ** 0.05, *** 0.01. "
		"(1)- First differences controlling for \$\Delta \ln(\text{pop}_{t-2})\$."
		"(2)- First differences controlling for \$\Delta \ln(\text{pop}_{t-2})\$ and \$\Delta \ln(\text{pop}_{t-3})\$."
		"(3)- Second differences regression."
		"(4)- Instrument \$\Delta \ln{(s_t)}\$ with \$\ln(s_{t-4})\$ controlling for \$\Delta \ln(\text{pop}_{t-2})\$."
		"(5)- Instrument \$\Delta \ln{(s_t)}\$ with \$\ln(s_{t-4})\$ controlling for \$\Delta \ln(\text{pop}_{t-2})\$ and \$\Delta \ln(\text{pop}_{t-3})\$."
		"(6)- Instrument \$\Delta \ln{(s_t)}\$ with \$\ln(s_{t-8})\$ controlling for \$\Delta \ln(\text{pop}_{t-2})\$."
        	"(7)- Instrument \$\Delta \ln{(s_t)}\$ with \$\ln(s_{t-4})\$ controlling for \$\ln(\text{pop}_{t-2})\$.");

***************;
*End of table 7;
***************;
};

	



if 1==1 {;
*******************************;
*Table A1: Subways first stage:;
*******************************;
	
	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	sort country urbancode year;
	xtset urbancode_n quinquenial;
	char year[omit] 2010;
	eststo clear; 		

	*(1);
		eststo:  xi: reg Dlop L4lop L2Dlpop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		test L4lop=0;
		local F= r(F);
		estadd scalar F_iv=`F';		
		sum L3lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;

	*(2)- ;
		eststo:  xi: reg Dlop L4lop L2Dlpop L3Dlpop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		test L4lop=0;
		local F= r(F);
		estadd scalar F_iv=`F';		
		sum L3lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;

	*(3)- ;
		eststo:  xi: reg Dlop L8lop L2Dlpop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		test L8lop=0;
		local F= r(F);
		estadd scalar F_iv=`F';		
		sum L4lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;

		
	*Table A1;		
		esttab using  "output/table_A1.tex", replace b(%10.3fc) se(3)  	
		label star(* 0.10 ** 0.05 *** 0.001) 	mtitles("\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$" "\$\Delta\ln{(s_t)}\$")
		order(  L4lop L8lop  L2Dlpop L3Dlpop  Dlgdp Dlcountry_pop)
		scalars("ymean Mean of dep. variable"  "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"   "F_iv Excluded instruments F-stat" "N Observations" )
		sfmt( %10.2f %10.2f %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.1f %10.2f ) obslast drop(_cons )
		indicate("YearXContinent dummies=*quiXcon*  *continent_*  *_Iquinqueni*")		
		substitute(\_ _)
		nonotes addnotes("Dependent variable: Change in log subway stations in a 5 year period."
		"Stars denote significance levels: * 0.10, ** 0.05, *** 0.01."
		"Sample is subway cities." 
		"City-level clustered standard errors in parentheses.");

****************;
*End of table A1;
****************;
};

		
		
if 1==1 {;
*****************;
*Figure A1 and A2;
*****************;

	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	sort country urbancode year;
	xtset urbancode_n quinquenial;
	char year[omit] 2010;
	eststo clear; 		
	keep if sub2010>0;

	*Plot system size against system age:;
		preserve;
		gen lop_rounded=round(lop, .5);
		sort subway_system_age lop ;
		by subway_system_age: egen snitt=mean(lop_rounded);
		lpoly lop subway_system_age if subway_system_age>=1, deg(1) bw(20) gen(x y) ci se(se1) nogr kernel(triangle);
		gen k=1.96;
		gen ci1l=y-k*se1;
		gen ci1h=y+k*se1;
		twoway (line y x, lpattern(solid) legend(off )) (scatter lop subway_system_age, msize(tiny) mcolor(black) jitter(2)  scheme(s1mono)	ylabels(0(1)6) xlabel(0(10)160) xtitle("Subway system age") ytitle("Log subways") );
		graph export "output/figure_A1.png", replace;
		restore;

	*Plot Dlop against L4lop:;
		label var L4lop "20 year lag log subways";
		twoway(scatter Dlop L4lop if L4lop>0 & Dlop<0.6, msize(tiny) mcolor(black) scheme(s1mono) )  (lfit Dlop L4lop if L4lop>0, lcolor(black) ytitle("Change in log subways") xtitle("20 year lag log subways") legend(off));				
		graph export "output/figure_A2.png", replace;

*********************;
*End of figure A1, A2;
*********************;
};




if 1==1 {;
*********************************;
*Table 8- Distributed lag models ;
*********************************;

	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	sort country urbancode year;
	xtset urbancode_n quinquenial;
	char year[omit] 2010;
	eststo clear; 		

	*(1)- ;
		eststo:  xi: reg Dlpop Dlop  Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0   , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(2)- ;
		eststo:  xi: reg Dlpop LDlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0   , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(3)- ;
		eststo:  xi: reg Dlpop L2Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0   , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	


	*(4)- ;
		eststo:  xi: reg Dlpop L3Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0   , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	

	*(5)- ;
		eststo:  xi: reg Dlpop Dlgdp Dlcountry_pop i.quinquenial*i.continent Dlop LDlop L2Dlop L3Dlop if sub2010>0   , cluster(urbancode) ;
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		estadd local FE  "No", replace;	
		
		esttab using  "output/table_8.tex", replace b(%10.3fc) se(3)  	
		label star(* 0.10 ** 0.05 *** 0.001) 	mtitles("\$\Delta\ln(\text{pop}_t)\$" "\$\Delta\ln(\text{pop}_t)\$" "\$\Delta\ln(\text{pop}_t)\$" "\$\Delta\ln(\text{pop}_t)\$" "\$\Delta\ln(\text{pop}_t)\$" )
		order(Dlop LDlop L2Dlop L3Dlop Dlgdp Dlcountry_pop)
		substitute(\_ _)
		scalars("ymean Mean of dep. variable"  "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"     "N Observations" )
		sfmt( %10.2f  %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.2f  %10.2f ) obslast drop(_cons ) 
		indicate("YearXContinent dummies=*quiXcon*  *continent_*  *_Iquinqueni*")		
		nonotes addnotes("Dependent variable: Change in log population in a 5 year period."
		"Sample is cities with subway in 2010. City-level clustered standard errors in parentheses." 
		"Stars denote significance levels: * 0.10, ** 0.05, *** 0.01.");

***************;
*End of table 8;
***************;
};


		
		
		
if 1==1 {;
**************************************************;
*Table 9- Robustness to confounding unobservables ;
**************************************************;

	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	sort country urbancode year;
	xtset urbancode_n quinquenial;
	*generate good for doing business variable:;
		sum doing_business_rank if  sub2010>0 ,d;
		gen good_doing_business=0 if sub2010>0  & doing_business_rank!=.;
		replace good_doing_business=1 if doing_business_rank<=r(p50)  & sub2010>0 & doing_business_rank!=.;
		gen good_doing_business_X_Dlop=good_doing_business*Dlop;
		label var good_doing_business_X_Dlop "\$\text{(Good doing business)} X \Delta \ln(s_t)\$";	

	*Generate coastal city indicator:;
		sum KM_OCEAN if year==2010,d;
		gen coastal_city=0;
		*as an example: bordeaux is borderline coastal with this cutoff.;
		replace coastal_city=1 if KM_OCEAN<20;
		gen coastal_city_X_Dlop=coastal_city*Dlop;
		label var coastal_city_X_Dlop "\$\text{(Coastal city)} X \Delta \ln \ln(s_t)\$";	

	*Share of subway coverage:;
		replace share_subwaylights_25km=0 if share_subwaylights_25km==. & sub2010>0;
		xtile t_shareoflights_25km = share_subwaylights_25km, nquantiles(3);
		tab  t_shareoflights_25km, gen(coverage_25km_);
		gen low_coverage_25km_X_Dlop=coverage_25km_1*Dlop;
		gen med_coverage_25km_X_Dlop=coverage_25km_2*Dlop;
		gen high_coverage_25km_X_Dlop=coverage_25km_3*Dlop;		
		label var low_coverage_25km_X_Dlop "\$\text{(Low initial subway coverage)} X \Delta \ln(s_t)\$";	
		label var med_coverage_25km_X_Dlop "\$\text{(Medium initial subway coverage)} X \Delta \ln(s_t)\$";	
		label var high_coverage_25km_X_Dlop "\$\text{(High initial subway coverage)} X \Delta \ln(s_t)\$";			

		xtile m_shareoflights_25km = share_subwaylights_25km, nquantiles(2);
		replace m_shareoflights_25km=0 if t_shareoflights_25km==1;
		replace m_shareoflights_25km=1 if t_shareoflights_25km==2;
		gen m_shareoflights_25km_X_Dlop=m_shareoflights_25km*Dlop;
		label var m_shareoflights_25km_X_Dlop "\$\text{(Subway coverage}>\text{median}) X \Delta \ln(s_t)\$";			

		gen post_1945=0;
		replace post_1945=1 if year_start>=1944 & sub2010>0;
		gen post_1945_X_Dlop=post_1945*Dlop;
		label var post_1945_X_Dlop "\$\text{(System built post WW II)} X \Delta \ln(s_t)\$";			

	*Above median slope in 50km, 25km, 10km:;
		foreach var in slope_50km slope_25km slope_10km elev_range_50km elev_range_25km elev_range_10km {;
		xtile q_`var' = `var' , nquantiles(2);
		replace q_`var'=0 if q_`var'==1;
		replace q_`var'=1 if q_`var'==2;
		gen q_`var'_X_Dlop=q_`var'*Dlop;
		};

		label var q_slope_50km_X_Dlop "\$\text{(50 km slope} > \text{median)} X \Delta \ln (s_t)\$";
		label var q_slope_25km_X_Dlop "\$\text{(25 km slope} > \text{median)} X \Delta \ln (s_t)\$";		
		label var q_slope_10km_X_Dlop "\$\text{(10 km slope} > \text{median)} X \Delta \ln (s_t)\$";		

		label var q_elev_range_50km_X_Dlop "\$\text{(50 km elevation range} > \text{median)} X \Delta \ln (s_t)\$";
		label var q_elev_range_25km_X_Dlop "\$\text{(25 km elevation range} > \text{median)} X \Delta \ln (s_t)\$";		
		label var q_elev_range_10km_X_Dlop "\$\text{(10 km elevation range} > \text{median)} X \Delta \ln (s_t)\$";		

		*create indicator for above median slope in 50km, 25km, 10km:;
		foreach var in rESRI_50km rESRI_1st_km_disk50km rESRI_2nd_km_disk50km rESRI_25km rESRI_1st_km_disk25km rESRI_2nd_km_disk25km  rESRI_10km rESRI_1st_km_disk10km rESRI_2nd_km_disk10km rESRI_05km rESRI_1st_km_disk05km rESRI_2nd_km_disk05km rESRI_1500m rESRI_2nd_km_disk1500m rESRI_1st_km_disk1500m {;
		xtile q_`var' = `var' , nquantiles(2);
		replace q_`var'=0 if q_`var'==1;
		replace q_`var'=1 if q_`var'==2;
		gen q_`var'_X_Dlop=q_`var'*Dlop;
		};
   
		label var q_rESRI_50km_X_Dlop "\$\text{(50km All roads} > \text{median)} X \Delta \ln(s_t)\$";
		label var q_rESRI_1st_km_disk50km_X_Dlop "\$\text{(50km highways} > \text{median)} X \Delta \ln(s_t)\$";		
		label var q_rESRI_2nd_km_disk50km_X_Dlop "\$\text{(50km secondary roads} > \text{median)} X \Delta \ln(s_t)\$";		

		label var q_rESRI_25km_X_Dlop "\$\text{(25km All roads} > \text{median)} X \Delta \ln(s_t)\$";
		label var q_rESRI_1st_km_disk25km_X_Dlop "\$\text{(25km highways} > \text{median)} X \Delta \ln(s_t)\$";		
		label var q_rESRI_2nd_km_disk25km_X_Dlop "\$\text{(25km secondary roads} > \text{median)} X \ln(s_t)\$";		

		label var q_rESRI_10km_X_Dlop "\$\text{(10km All roads} > \text{median)} X \Delta \ln(s_t)\$";
		label var q_rESRI_1st_km_disk10km_X_Dlop "\$\text{(10km highways} > \text{median)} X \Delta \ln(s_t)\$";		
		label var q_rESRI_2nd_km_disk10km_X_Dlop "\$\text{(10km secondary roads} > \text{median)} X \Delta \ln(s_t)\$";		

		label var q_rESRI_05km_X_Dlop "\$\text{(5km All roads} > \text{median)} X \Delta \ln(s_t)\$";
		label var q_rESRI_1st_km_disk05km_X_Dlop "\$\text{(5km highways} > \text{median)} X \Delta \ln(s_t)\$";		
		label var q_rESRI_2nd_km_disk05km_X_Dlop "\$\text{(5km secondary roads} > \text{median)} X \ln(s_t)\$";		

		label var q_rESRI_1500m_X_Dlop "\$\text{(1.5km All roads} > \text{median)} X \Delta \ln(s_t)\$";
		label var q_rESRI_1st_km_disk1500m_X_Dlop "\$\text{(1.5km highways} > \text{median)} X \Delta \ln(s_t)\$";		
		label var q_rESRI_2nd_km_disk1500m_X_Dlop "\$\text{(1.5km secondary roads} > \text{median)} X \Delta \ln(s_t)\$";		

		gen log_rESRI_1500m=log(rESRI_1500m);

		*Interaction Dlop ;
		gen IntrixIndex_X_Dlop=IntrixIndex*Dlop;
		gen tomtom_index=219-tomtom_ranking;
		gen Tomtom_X_Dlop=tomtom_index*Dlop;
		gen capital_X_Dlop=capital*Dlop;
		label var Tomtom_X_Dlop "\$\text{(TomTom congestion index)} X \Delta \ln (s_t)\$";	
		label var IntrixIndex_X_Dlop "\$\text{(Intrix congestion index)} X \Delta \ln (s_t)\$";	
		label var capital_X_Dlop "\$\text{(Capital)} X \Delta \ln (s_t)\$";	
	
		*Indicator for above median:;
		foreach var in tomtom_index IntrixIndex {;
		xtile q_`var' = `var' , nquantiles(2);
		replace q_`var'=0 if q_`var'==1;
		replace q_`var'=1 if q_`var'==2;
		gen q_`var'_X_Dlop=q_`var'*Dlop;
		};

		label var q_tomtom_index_X_Dlop "\$\text{(TomTom congestion} > \text{median)} X \Delta \ln (s_t)\$";
		label var q_IntrixIndex_X_Dlop "\$\text{(Intrix congestion} > \text{median)} X \Delta \ln (s_t)\$";		

		*Indicator for above median bus ridership per capita in 2010:;
		xtile q_bus_ridership_pc_aux = bus_ridership_pc if  sub2010>0 & year==2010, nquantiles(2);
		egen q_bus_ridership_pc=max(q_bus_ridership_pc_aux ) ,by(urbancode);
		replace q_bus_ridership_pc=0 if q_bus_ridership_pc==1;
		replace q_bus_ridership_pc=1 if q_bus_ridership_pc==2;
		drop q_bus_ridership_pc_aux;
		gen q_bus_ridership_pc_X_Dlop=q_bus_ridership_pc*Dlop;
		label var q_bus_ridership_pc_X_Dlop "\$\text{(Bus ridership pc} > \text{median)} X \Delta \ln (s_t)\$";	

		*Indicator for above median city size in 1950:;
		xtile q_pop_aux = pop if  sub2010>0 & year==1950, nquantiles(2);
		egen q_pop=max(q_pop_aux ) ,by(urbancode);
		replace q_pop=0 if q_pop==1;
		replace q_pop=1 if q_pop==2;
		drop q_pop_aux;
		gen q_pop_X_Dlop=q_pop*Dlop;
		label var q_pop_X_Dlop "\$\text{(City pop. 1950} > \text{median)} X \Delta \ln (s_t)\$";	

		tempfile het_effects;
		save `het_effects';
	
		*Ommitted year:;
		char year[omit] 2010;
		eststo clear; 

	*(1) - Baseline specification;
		eststo:  xi: reg Dlpop Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(2) - Interact with 25k slope>median;
		eststo:  xi: reg Dlpop Dlop q_slope_25km_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(3) - Interact with 25k elevation range>median;
		eststo:  xi: reg Dlpop Dlop q_elev_range_25km_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(4) - Interact with 25 km highways>median;
		eststo:  xi: reg Dlpop Dlop q_rESRI_1st_km_disk25km_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(5) - Interact with Congestion>median;
		eststo:  xi: reg Dlpop Dlop q_tomtom_index_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(6) - Interact with capital dummy;
		eststo:  xi: reg Dlpop Dlop capital_X_Dlop  Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
	
	*(7) Interact with good_doing_business_X_Dlopabove median;
		eststo:  xi: reg Dlpop Dlop  good_doing_business_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(8) Interact with post WWII;
		eststo:  xi: reg Dlpop Dlop  post_1945_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(9) Interact with centralized>median;
		use "data/analyze_me2_lights.dta",clear;
		sum linear_b1 if year==1995 & sub2010>0,d ;
		gen y=0 if year==1995 & sub2010>0;
		replace y=1 if linear_b1<r(p50)  & year==1995 & sub2010>0; 
		*NOTE that more centralized means more negative slope;
		egen centralized_gradient_1995=max(y) if sub2010>0,by(urbancode);
		drop y;
		gen centralized_gradient_X_Dlop=centralized_gradient_1995*Dlop;
		label var centralized_gradient_X_Dlop "\$\text{(Centralized} > \text{median)} X \Delta \ln (s_t)\$";	
		*Interact Dlop with absolute value of light gradient measure:;
		gen x=abs(linear_b1)  if  sub2010>0 & year==1995;
		egen centralization_95=max(x) ,by(urbancode);
		gen centralization_95_X_Dlop=centralization_95*Dlop;
		label var centralization_95_X_Dlop "\$\text{Centralization} X \Delta \ln (s_t)\$";	
		*NOTE: need to add the label by hand in the table, since changing datasets loses the label var; 
		eststo:  xi: reg Dlpop Dlop   centralization_95_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(10) Interact with subway coverage >median;
		use `het_effects',clear;
		char year[omit] 2010;
		eststo:  xi: reg Dlpop Dlop m_shareoflights_25km_X_Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
		
	*(11)- Interact with city size>median;
		eststo:  xi: reg Dlpop q_pop_X_Dlop Dlgdp Dlcountry_pop Dlop   i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(12) Coastal city;
		eststo:  xi: reg Dlpop coastal_city_X_Dlop Dlgdp Dlcountry_pop Dlop   i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(13)- interact with bus ridership above median;
		eststo:  xi: reg Dlpop q_bus_ridership_pc_X_Dlop Dlgdp Dlcountry_pop Dlop   i.quinquenial*i.continent if  sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlog_op_km if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

		esttab using  "output/table_9.tex", replace b(%10.3fc) se(3)  
		label star(* 0.10 ** 0.05 *** 0.001) 	
		nomtitles
		order(Dlop q_slope_25km_X_Dlop  q_elev_range_25km_X_Dlop  q_rESRI_1st_km_disk25km_X_Dlop  q_tomtom_index_X_Dlop capital_X_Dlop good_doing_business_X_Dlop  post_1945_X_Dlop   centralization_95_X_Dlop  m_shareoflights_25km_X_Dlop q_pop_X_Dlop coastal_city_X_Dlop q_bus_ridership_pc_X_Dlop Dlgdp Dlcountry_pop )
		substitute(\_ _)				
		scalars("ymean Mean of dep. variable"  "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"   "N Observations" )
		sfmt( %10.2f  %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.2f %10.2f %10.1f %10.2f ) obslast drop(_cons ) 
		indicate("YearXContinent dummies=*quiXcon*  *continent_*  *_Iquinqueni*")		
		nonotes addnotes("Dependent variable: Change in log population in a 5 year period. Sample is subway cities in 2010. City-level clustered standard errors in parentheses." 
		"Stars denote significance levels: * 0.10, ** 0.05, *** 0.01.");
		eststo clear; 		

***************;
*End of table 9;
***************;
};


		
if 1==1 {;
****************************************************************;
*Table 10- Decentralization- Radiance calibrated light gradient ;
****************************************************************;

	use "data/analyze_me2_lights.dta",clear;
	char year[omit] 1995;

	*(1) Pooled OLS;
		eststo: xi: reg linear_b1 lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent if sub2010>0, cluster(urbancode) ; 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(2) FD;	
		eststo:  xi: reg Dlinear_b1 Dlop Dlgdp Dlcountry_pop  i.quinquenial*i.continent if sub2010>0, cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(3) FD, control for lagged pop growth;		
		eststo:  xi: reg Dlinear_b1 Dlop Dlgdp Dlcountry_pop L2lpop i.quinquenial*i.continent if sub2010>0, cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;
	
	*(4) FD-IV;				
		xi: reg Dlop L4lop Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		test L4lop=0;
		local F= r(F);
		eststo:  xi: ivregress 2sls Dlinear_b1 Dlgdp Dlcountry_pop i.quinquenial*i.continent  (Dlop=L4lop) if sub2010>0 , cluster(urbancode);
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(5) FD-IV, control for lagged pop growth;				
		xi: reg Dlop L4lop Dlgdp Dlcountry_pop D2lpop i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		test L4lop=0;
		local F= r(F);
		eststo:  xi: ivregress 2sls Dlinear_b1 Dlgdp Dlcountry_pop L2lpop i.quinquenial*i.continent  (Dlop=L4lop) if sub2010>0 , cluster(urbancode);
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;


	*Table 10 Panel A:;		
		esttab using  "output/table_10_A.tex", replace b(a2) se(a2) 	
		label star(* 0.10 ** 0.05 *** 0.001)
		mtitles("OLS" "OLS-FD" "OLS-FD" "2SLS-FD" "2SLS-FD")
		order(Dlop lop Dlgdp Dlcountry_pop lgdp lcountry_pop L2lpop)
		substitute(\_ _)
		scalars("ymean Mean of dep. variable"  "mean_sub Mean of subways regressor\$\;\;\;\;\;\;\;\;\$" "sd_sub SD subways regressor" "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"   "N Observations" )
		sfmt(%10.3f %10.2f %10.2f %10.2f %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.2f ) obslast drop(_cons ) 
		indicate("Geographic controls=lKM_OCEAN lKM_RIVER lKM_BORDER capital _Icontinent_*" "YearXContinent dummies=*quiXcon*   _Iquinqueni* *_Iquinqueni*")
		nonotes addnotes("For each  city-year, a linear regression was estimated between the log mean radiance calibrated" 
				 "light intensity in successive rings at 0-1.5km, 1.5-5km, 5-10km, 10-25km and 25-50km and log "
				 "distance from the city center centroid. Col. 1 dependent variable is the slope of the light "
				 "gradient in a city-year period. Columns 2-5 use as dependent variable the change in slope over "  
				 "a 5 year period. City-level robust standard errors in parentheses."
				 "Stars denote significance levels: * 0.10, ** 0.05, *** 0.01.");

		
	*Table 10 Panel B:;

	*(1) Pooled OLS;
		eststo clear; 	
		eststo: xi: reg linear_b0 lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent if sub2010>0, cluster(urbancode) ; 		
		actest, lags(3);				
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(2) FD;	
		eststo:  xi: reg Dlinear_b0 Dlop Dlgdp Dlcountry_pop  i.quinquenial*i.continent if sub2010>0, cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(3) FD, control for lagged pop growth;		
		eststo:  xi: reg Dlinear_b0 Dlop Dlgdp Dlcountry_pop L2lpop i.quinquenial*i.continent if sub2010>0, cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	
	*(4) FD-IV;				
		xi: reg Dlop L4lop Dlgdp Dlcountry_pop i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		test L4lop=0;
		local F= r(F);
		eststo:  xi: ivregress 2sls Dlinear_b0 Dlgdp Dlcountry_pop i.quinquenial*i.continent  (Dlop=L4lop) if sub2010>0 , cluster(urbancode);
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(5) FD-IV, control for lagged pop growth;				
		xi: reg Dlop L4lop Dlgdp Dlcountry_pop D2lpop i.quinquenial*i.continent if  sub2010>0  , cluster(urbancode);
		test L4lop=0;
		local F= r(F);
		eststo:  xi: ivregress 2sls Dlinear_b0 Dlgdp Dlcountry_pop L2lpop i.quinquenial*i.continent  (Dlop=L4lop) if sub2010>0 , cluster(urbancode);
		estadd scalar F_iv=`F';		
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*Table 10 Panel B:;		
		esttab using  "output/table_10_B.tex", replace b(a2) se(a2) 	
        	label star(* 0.10 ** 0.05 *** 0.001)
		mtitles("OLS" "OLS-FD" "OLS-FD" "2SLS-FD" "2SLS-FD")
		order(Dlop lop Dlgdp Dlcountry_pop lgdp lcountry_pop L2lpop)
		substitute(\_ _)
		scalars("ymean Mean of dep. variable"  "mean_sub Mean of subways regressor\$\;\;\;\;\;\;\;\;\$" "sd_sub SD subways regressor" "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"   "N Observations" )
		sfmt(%10.3f %10.2f %10.2f %10.2f %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.2f ) obslast drop(_cons ) 
		indicate("Geographic controls=lKM_OCEAN lKM_RIVER lKM_BORDER capital _Icontinent_*" "YearXContinent dummies=*quiXcon*   _Iquinqueni* *_Iquinqueni*")
		nonotes addnotes("For each  city-year, a linear regression was estimated between the log mean radiance calibrated" 
				 "light intensity in successive rings at 0-1.5km, 1.5-5km, 5-10km, 10-25km and 25-50km and log "
				 "distance from the city center centroid. Col. 1 dependent variable is the slope of the light "
				 "gradient in a city-year period. Columns 2-5 use as dependent variable the change in slope over "  
				 "a 5 year period. City-level robust standard errors in parentheses."
				 "Stars denote significance levels: * 0.10, ** 0.05, *** 0.01.");

****************;
*End of table 10;
****************;
};



if 1==1 {;
************************************************;
*Table 11- Log ridership - Pooled cross section ;
************************************************;
	
	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	tsset urbancode_n quinquenial;
	sort urbancode_n quinquenial;
	char year[omit] 2010;
	eststo clear; 		

	*(1)-Sample: all, x's lop;
		cap drop resid Lresid x nvals;
		eststo: reg log_ridership_sub_and_bus lop , cluster(urbancode);
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;


	*(2)-Sample: all, x's lop, lgdp, logcountry pop, year*continent dummies, geography;
		eststo: xi: reg log_ridership_sub_and_bus lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent , cluster(urbancode); 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(3)-Sample: all, x's lop;
		cap drop resid Lresid x nvals;
		eststo: reg log_ridershipheavyrail lop , cluster(urbancode);
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;


	*(4)-Sample: all, x's lop, lgdp, logcountry pop, year*continent dummies, geography;
		eststo: xi: reg log_ridershipheavyrail  lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent , cluster(urbancode); 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;


	*(5)-Sample: all, x's lop;
		cap drop resid Lresid x nvals;
		eststo: reg log_ridershipbuses lop , cluster(urbancode);
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;


	*(6)-Sample: all, x's lop, lgdp, logcountry pop, year*continent dummies, geography;
		eststo: xi: reg log_ridershipbuses lop lgdp lcountry_pop capital lKM_OCEAN lKM_RIVER lKM_BORDER  i.quinquenial*i.continent , cluster(urbancode); 		
		estadd ysumm;
		sum lop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

		esttab using  "output/table_11.tex", replace b(%10.2fc) se(2)  	
		label star(* 0.10 ** 0.05 *** 0.001)
		mgroups("\multicolumn{2}{c}{\$\ln(\text{All ridership}_t)\$}&\multicolumn{2}{c}{\$\ln(\text{Subway ridership}_t)\$} &\multicolumn{2}{c}{\$\ln(\text{Bus ridership}_t)\$} \\ \cmidrule(r){2-3} \cmidrule(r){4-5}  \cmidrule(r){6-7} ")
		nomtitles
		order(lop lgdp lcountry_pop)
		scalars("ymean Mean of dep. variable"  "mean_sub Mean of subways regressor" "sd_sub SD subways regressor" "N Observations" "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods" )
		sfmt(%10.2f %10.2f %10.2f %10.2f %10.2f %10.0f %10.0f %10.0f )
		obslast substitute(\_ _) drop(_cons  ) 	indicate("Geographic controls=lKM_OCEAN lKM_RIVER lKM_BORDER capital _Icontinent_*" "YearXContinent dummies=*quiXcon*   _Iquinqueni* *_Iquinqueni*")
		nonotes addnotes("Dependent variable: Log ridership of subways and buses in metropolitan area in period t." 
		"City-level clustered standard errors in parentheses. Stars denote significance levels: * 0.10, ** 0.05, *** 0.01."
		"Geographic controls are capital city dummy, log km to ocean, log km to land border, and log km to major" 
		"navigable river. (Odd columns)-Pooled cross section. (Even columns)-Add geographic controls, GDP pc control, "
		"country population, and yearXcontinent dummies.");

****************;
*End of table 11;
****************;
};




if 1==1 {;
*********************************************;
*Table 12- Log ridership - First differences ;
*********************************************;
	
	use "data/analyze_me2.dta",clear;
	keep if !mod(year,5);
	drop if year<1950;
	gen quinquenial=year/5-389;
	sort country urbancode year;
	xtset urbancode_n quinquenial;
	char year[omit] 2010;
	eststo clear; 		

	*(1)- FD regression, no controls. Sample: Subway cities ;
		eststo:  xi: reg Dlog_ridership_sub_and_bus Dlop if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(2)- Add yarXcontinent time trends;
		eststo: xi: reg Dlog_ridership_sub_and_bus Dlop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode) ;
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(3)- Add other controls.;
		eststo:  xi: reg Dlog_ridership_sub_and_bus Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		*note stata does not perform 1 sided tests, so we calculate it from the two sided test:;
		test _b[Dlop]=1;
		local sign_Dlop=sign(_b[Dlop]);
		display "H0: coef<1 p-value =" ttail(r(df_r),`sign_Dlop'*sqrt(r(F)));
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(4)- FD regression, no controls. Sample: Subway cities ;
		eststo:  xi: reg Dlog_ridershipheavyrail Dlop if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(5)- Add yarXcontinent time trends;
		eststo: xi: reg Dlog_ridershipheavyrail Dlop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode) ;
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(6)- Add other controls.;
		eststo:  xi: reg Dlog_ridershipheavyrail Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		*note stata does not perform 1 sided tests, so we calculate it from the two sided test:;
		test _b[Dlop]=1;
		local sign_Dlop=sign(_b[Dlop]);
		display "H0: coef<1 p-value =" ttail(r(df_r),`sign_Dlop'*sqrt(r(F)));
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(7)- FD regression, no controls. Sample: Subway cities ;
		eststo:  xi: reg Dlog_ridershipbuses Dlop if sub2010>0 , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(8)- Add yarXcontinent time trends;
		eststo: xi: reg Dlog_ridershipbuses Dlop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode) ;
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

	*(9)- Add other controls.;
		eststo:  xi: reg Dlog_ridershipbuses Dlop Dlgdp Dlcountry_pop i.quinquenial*i.continent if sub2010>0  , cluster(urbancode);
		estadd ysumm;
		sum Dlop if e(sample);
		estadd scalar mean_sub=r(mean);
		estadd scalar sd_sub=r(sd);
		cap drop x;
		gen x=year if e(sample); by x, sort: gen nvals = _n == 1; replace nvals = sum(nvals); replace nvals=. if e(sample)==0; sum nvals; sort urbancode_n year;
		estadd scalar year=r(max); 
		gen s=urbancode_n if e(sample) & sub2010==1; by s, sort: gen svals = _n == 1; replace svals = sum(svals); sum svals; sort urbancode_n year;
		estadd scalar sub_cities=r(max)-1; drop s svals nvals x;

		esttab using  "output/table_12.tex", replace b(%10.3fc) se(3)  	
		label star(* 0.10 ** 0.05 *** 0.001) 	
		mgroups("\multicolumn{3}{c}{\$ \Delta \ln(\text{All ridership}_t)\$}&\multicolumn{3}{c}{\$  \Delta \ln(\text{Subway ridership}_t)\$} &\multicolumn{3}{c}{\$ \Delta \ln(\text{Bus ridership}_t)\$} \\ ")
		nomtitles
		order(Dlop Dlgdp Dlcountry_pop)
		substitute(\_ _)
		scalars("ymean Mean of dep. variable"  "mean_sub Mean of subways regressor" "sd_sub SD subways regressor" "r2 R-squared" "N_clust Number of cities" "sub_cities Number of subway cities" "year Number of periods"    "N Observations" )
		sfmt(%10.3f %10.2f %10.2f %10.2f %10.0f %10.0f %10.0f %10.2f %10.2f %10.2f %10.2f ) obslast drop(_cons ) 
		indicate("YearXContinent dummies=*quiXcon*    *_Iquinqueni*"  "Continent dummies=_Icontinent_* *continent_*" )
 		nonotes addnotes("Dependent variable: Change in log ridersip of metropolitan area in a 5 year period. Sample is subway cities."
		"City-level clustered standard errors in parentheses. Stars denote significance levels: * 0.10, ** 0.05, *** 0.01. "
		"(1)- No controls. (2)-Add yearXcontinent dummies (3)-Add log gdp and log country pop. controls. ");

****************;
*End of table 12;
****************;
};


erase "data/analyze_me2_lights.dta";
log close;

